@@ -82,6 +82,7 @@ EditMountPointDialogWidget::EditMountPointDialogWidget(QWidget* parent, Partitio
     boxOptions()[QStringLiteral("sync")] = m_CheckSync;
     boxOptions()[QStringLiteral("noexec")] = m_CheckNoExec;
     boxOptions()[QStringLiteral("relatime")] = m_CheckRelAtime;
+    boxOptions()[QStringLiteral("nofail")] = m_CheckNoFail;
 
     setupRadio(currentEntry->entryType());
     setupOptions(currentEntry->options());
@@ -241,6 +242,13 @@ void EditMountPointDialogWidget::currentPathChanged(const QString &newPath)
     } else {
         m_valid = true;
         m_PathMessage->setVisible(false);
+        if (path == QStringLiteral("/") || QDir(path).canonicalPath() == QStringLiteral("/home"))
+            m_CheckNoFail->setCheckState(Qt::Unchecked);
+        else
+            m_CheckNoFail->setCheckState(Qt::Checked);
     }
     Q_EMIT isValidChanged(m_valid);
 }
+
+
+#include "moc_editmountpointdialogwidget.cpp"
